[−][src]Struct ttv_pubsub::channel_bits::BitsEventData
Data for bits event
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.badge_entitlement: Option<BadgeEntitlement>If set, describes new unlocked badge for user
bits_used: i64The number of bits that were sent.
channel_id: StringID of channel where message was sent
channel_name: StringUsername of channel where message was sent
chat_message: StringThe full message that was sent with the bits.
context: BitsContextContext of bits_event, seems to only be cheer
is_anonymous: boolWhether the cheer was anonymous.
time: StringTime when pubsub message was sent
total_bits_used: i64The total number of bits that were ever sent by the user in the channel.
user_id: StringID of user that sent message
user_name: StringName of user that sent message