[−][src]Enum ttv_pubsub::moderation::ModerationActionCommand
A command
Variants (Non-exhaustive)
Delete
Given when a message is deleted with /delete <msg-id>
Timeout
Given when a user is timed-out with /timeout <user> <time> <reason>
Mod
Given when a user is added as a moderator. /mod <user>.
See ChatModeratorActionsReply::ModeratorAdded where this is given
Unmod
Given when a user is removed as a moderator, /unmod <user>
Modified automod properties
Given when automod config is changed. I.e filtering changed etc
Ban
Given when a user is banned with /timeout <user> <reason>
Unban
Given when a user is unbanned with /unban <user> or /untimeout <user>
Automod message rejected
Automod permitted term added
Automod permitted term removed
Automod blocked term added
Automod blocked term removed
Automod message denied
Raid
Given when editor/broadcaster does /raid <channel>
Slow-mode chat enabled
Slow-mode chat disabled
Followers-only chat enabled
Followers-only chat disabled
Subscriber-only chat enabled
Subscriber-only chat disabled
Emote-only chat enabled
Emote-only chat disabled
Chat cleared for all viewers
Unique chat enabled
Unique chat disabled
User added as VIP
User removed as VIP
Channel host started
Channel host removed