[−][src]Enum ttv_pubsub::channel_subscriptions::ChannelSubscribeEventsV1Reply
Reply from ChannelSubscribeEventsV1
Variants (Non-exhaustive)
A subscription
Fields of Sub
benefit_end_month: i64Unknown
channel_id: StringID of the channel that has been subscribed or subgifted
channel_name: StringName of the channel that has been subscribed or subgifted
cumulative_months: i64Cumulative months that user has been subscribed
is_gift: boolResubscription is a gift
multi_month_duration: i64Duration of subscription, e.g 1, 3 or 6
sub_message: SubMessageMessage sent with this subscription
sub_plan: SubscriptionTierSubscription plan
sub_plan_name: StringName of subscription plan
time: StringTime when pubsub message was sent
user_id: StringID of user that subscribed
user_name: StringUsername of user that subscribed
display_name: StringDisplay name of user that subscribed
A resubscription
Fields of ReSub
benefit_end_month: Option<i64>Unknown
channel_id: StringID of the channel that has been subscribed or subgifted
channel_name: StringName of the channel that has been subscribed or subgifted
cumulative_months: i64Cumulative months that user has been subscribed
is_gift: boolResubscription is a gift
streak_months: Option<i64>Months the user has been subscribed for in a row.
multi_month_duration: Option<i64>Duration of subscription, e.g 1, 3 or 6
sub_message: SubMessageMessage sent with this subscription
sub_plan: SubscriptionTierSubscription plan
sub_plan_name: StringName of subscription plan
time: StringTime when pubsub message was sent
user_id: StringID of user that subscribed
user_name: StringUsername of user that subscribed
display_name: StringDisplay name of user that subscribed
A gifted subscription happened
Fields of SubGift
benefit_end_month: Option<i64>Unknown
channel_id: StringID of the channel that has been subscribed or subgifted
channel_name: StringName of the channel that has been subscribed or subgifted
months: i64Months
multi_month_duration: Option<i64>Duration of subscription, e.g 1, 3 or 6
recipient_display_name: StringDisplay name of user that received gifted subscription
recipient_id: StringUsername of user that received gifted subscription
recipient_user_name: StringUsername of user that received gifted subscription
sub_plan: SubscriptionTierSubscription plan
sub_plan_name: StringName of subscription plan
time: StringTime when pubsub message was sent
user_id: StringID of user that purchased gifted subscription
user_name: StringUsername of user that purchased gifted subscription
display_name: StringDisplay name of user that purchased gifted subscription